@@ -99,7 +99,7 @@ class DomaPanDAWork(Work):
         return False
 
     def load_panda_config(self):
-        panda_config = ConfigParser.SafeConfigParser()
+        panda_config = ConfigParser.ConfigParser()
         if os.environ.get('IDDS_PANDA_CONFIG', None):
             configfile = os.environ['IDDS_PANDA_CONFIG']
             if panda_config.read(configfile) == [configfile]:
@@ -266,8 +266,8 @@ class DomaPanDAWork(Work):
         for input_d in inputs_dependency:
             task_name = input_d['task']
             if (task_name not in task_name_to_coll_map                    # noqa: W503
-                or 'outputs' not in task_name_to_coll_map[task_name]      # noqa: W503
-                or not task_name_to_coll_map[task_name]['outputs']):      # noqa: W503
+               or 'outputs' not in task_name_to_coll_map[task_name]      # noqa: W503
+               or not task_name_to_coll_map[task_name]['outputs']):      # noqa: W503
                 return False
         return True
 
